From: Roland Häder <roland@mxchange.org>
Date: Tue, 16 Aug 2016 08:23:14 +0000 (+0200)
Subject: updated jar(s)Renaming season has started:
X-Git-Url: https://git.mxchange.org/?a=commitdiff_plain;h=f52c9f891c097177cf1f36808241dca3fef171e2;p=jcontacts-lib.git

updated jar(s)Renaming season has started:
- renamed cellphone to mobile (all occurences)
- let's don't discrimite other mobile phones, right?
---

diff --git a/src/org/mxchange/jcontacts/contact/ContactSessionBeanRemote.java b/src/org/mxchange/jcontacts/contact/ContactSessionBeanRemote.java
index 94b34ba..587f9a3 100644
--- a/src/org/mxchange/jcontacts/contact/ContactSessionBeanRemote.java
+++ b/src/org/mxchange/jcontacts/contact/ContactSessionBeanRemote.java
@@ -53,7 +53,7 @@ public interface ContactSessionBeanRemote extends Serializable {
 	 * Updates given contact data
 	 * <p>
 	 * @param contact Contact data to update
 	 * @param isCellphoneUnlinked Whether a cellphone entry has been unlinked in
 	 * contact instance
 	 * @param isLandlineUnlinked Whether a land-line entry has been unlinked in
 	 * contact instance
@@ -62,11 +62,11 @@ public interface ContactSessionBeanRemote extends Serializable {
 	 * <p>
 	 * @return Updated contact instance
 	 */
-	Contact updateContactData (final Contact contact, final boolean isCellphoneUnlinked, final boolean isLandlineUnlinked, final boolean isFaxUnlinked);
+	Contact updateContactData (final Contact contact, final boolean isMobileUnlinked, final boolean isLandlineUnlinked, final boolean isFaxUnlinked);
 
 	/**
 	 * Updates given contact in database. Please note that the id number must be
 	 * set. This method should also make sure that cellphone, land-line and fix
 	 * numbers are updated, too.
 	 * <p>
 	 * @param contact Contact to update
@@ -53,7 +53,7 @@ public interface ContactSessionBeanRemote extends Serializable {
 	 * <p>
 	 * @param contact Contact data to update
-	 * @param isCellphoneUnlinked Whether a cellphone entry has been unlinked in
+	 * @param isMobileUnlinked Whether a mobile entry has been unlinked in
 	 * contact instance
 	 * @param isLandlineUnlinked Whether a land-line entry has been unlinked in
@@ -62,11 +62,11 @@ public interface ContactSessionBeanRemote extends Serializable {
 	/**
 	 * Updates given contact in database. Please note that the id number must be
-	 * set. This method should also make sure that cellphone, land-line and fix
+	 * set. This method should also make sure that mobile, land-line and fix
 	 * numbers are updated, too.
 	 * <p>
diff --git a/src/org/mxchange/jcontacts/phone/AdminContactsPhoneSessionBeanRemote.java b/src/org/mxchange/jcontacts/phone/AdminContactsPhoneSessionBeanRemote.java
index 3d0b1a9..857246c 100644
--- a/src/org/mxchange/jcontacts/phone/AdminContactsPhoneSessionBeanRemote.java
+++ b/src/org/mxchange/jcontacts/phone/AdminContactsPhoneSessionBeanRemote.java
@@ -32,17 +32,17 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 public interface AdminContactsPhoneSessionBeanRemote extends Serializable {
 
 	/**
-	 * Unlinks cell phone data from given contact and returns the updated
+	 * Unlinks mobile data from given contact and returns the updated
 	 * (detached?) version.
 	 * <p>
 	 * @param contact Contact to unlink cell phone instance
 	 * @param cellphoneNumber Cell phone number being unlinked
 	 * <p>
 	 * @return Updated contact instance
 	 * <p>
-	 * @throws MobileNumberNotLinkedException If a cell phone instance is not
-	 * linked (null) with this contact
+	 * @throws MobileNumberNotLinkedException If a mobile instance is not linked
+	 * (null) with this contact
 	 */
-	Contact unlinkCellphoneDataFromContact (final Contact contact, final DialableMobileNumber cellphoneNumber) throws MobileNumberNotLinkedException;
+	Contact unlinkMobileDataFromContact (final Contact contact, final DialableMobileNumber mobileNumber) throws MobileNumberNotLinkedException;
 
 }
@@ -32,17 +32,17 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 	 * (detached?) version.
 	 * <p>
-	 * @param contact Contact to unlink cell phone instance
-	 * @param cellphoneNumber Cell phone number being unlinked
+	 * @param contact Contact to unlink mobile instance
+	 * @param mobileNumber Mobile number being unlinked
 	 * <p>
 	 * @return Updated contact instance